@@ -1889,6 +1889,7 @@ class SharePointClient:
         list_item: ClientObject,
     ) -> Craniotomy:
         """Maps a SharePoint ListItem to a Craniotomy model"""
+        # TODO: missing fields (craniotomy coords,hemisphere)
         list_fields = NeurosurgeryAndBehaviorList2023.ListField
         start_date = map_date_to_datetime(
             list_item.get_property(list_fields.DATE_OF_SURGERY.value)
@@ -1897,10 +1898,28 @@ class SharePointClient:
         experimenter_full_name = self._map_experimenter_name(
             list_item, list_fields
         )
+        iacuc_protocol = list_item.get_property(
+            list_fields.IACUC_PROTOCOL.value
+        )
+        animal_weight_prior = parse_str_into_float(
+            list_item.get_property(list_fields.WEIGHT_BEFORE_SURGER.value)
+        )
+        animal_weight_post = parse_str_into_float(
+            list_item.get_property(list_fields.WEIGHT_AFTER_SURGERY.value)
+        )
+        craniotomy_type = list_item.get_property(
+            list_fields.CRANIOTOMY_TYPE.value
+        )
+        craniotomy_size = parse_str_into_float(craniotomy_type)
         craniotomy = Craniotomy.construct(
             start_date=start_date,
             end_date=end_date,
             experimenter_full_name=experimenter_full_name,
+            iacuc_protocol=iacuc_protocol,
+            animal_weight_prior=animal_weight_prior,
+            animal_weight_post=animal_weight_post,
+            craniotomy_type=craniotomy_type,
+            craniotomy_size=craniotomy_size,
         )
         return craniotomy
 
