@@ -528,10 +528,12 @@ class Examples:
             start_date=datetime.date(2022, 1, 3),
             end_date=datetime.date(2022, 1, 3),
             experimenter_full_name="NSB-187",
-            iacuc_protocol=None,
-            animal_weight_prior=None,
-            animal_weight_post=None,
+            iacuc_protocol="2103",
+            animal_weight_prior=25.2,
+            animal_weight_post=28.2,
             procedure_type="Craniotomy",
+            craniotomy_type="5mm",
+            craniotomy_size=5.0,
             craniotomy_hemisphere=None,
             craniotomy_coordinates_ml=None,
             craniotomy_coordinates_ap=None,
